@@ -2,20 +2,49 @@ from typing import List, Optional, Union
 
 import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
+from sklearn.utils import deprecated
 from sklearn.utils.validation import check_is_fitted
 
 from feature_engine.dataframe_checks import (
     _check_contains_inf,
     _check_contains_na,
-    _check_input_matches_training_df,
-    _is_dataframe,
+    _check_X_matches_training_df,
+    check_X,
 )
-from feature_engine.validation import _return_tags
+from feature_engine._docstrings.methods import (
+    _fit_not_learn_docstring,
+    _fit_transform_docstring,
+)
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+)
+from feature_engine._docstrings.class_inputs import (
+    _drop_original_docstring,
+    _missing_values_docstring,
+)
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.tags import _return_tags
 from feature_engine.variable_manipulation import _find_or_check_numerical_variables
 
 
+@deprecated(
+    "CombineWithReferenceFeature() is deprecated in version 1.3 and will be removed in "
+    "version 1.5. Use RelativeFeatures() instead."
+)
+@Substitution(
+    missing_values=_missing_values_docstring,
+    drop_original=_drop_original_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    fit=_fit_not_learn_docstring,
+    fit_transform=_fit_transform_docstring,
+)
 class CombineWithReferenceFeature(BaseEstimator, TransformerMixin):
     """
+    **DEPRECATED: CombineWithReferenceFeature() is deprecated in version 1.3 and will be
+    removed in Version 1.5. Use RelativeFeatures() instead.**
+
     CombineWithReferenceFeature() applies basic mathematical operations between a group
     of variables and one or more reference features. It adds one or more additional
     features to the dataframe with the result of the operations.
@@ -24,102 +53,64 @@ class CombineWithReferenceFeature(BaseEstimator, TransformerMixin):
     divides a group of features to / by a group of reference variables, and returns the
     result as new variables in the dataframe.
 
-    For example, if we have the variables **number_payments_first_quarter**,
-    **number_payments_second_quarter**, **number_payments_third_quarter**,
-    **number_payments_fourth_quarter**, and **total_payments**, we can use
-    CombineWithReferenceFeature() to determine the percentage of payments per
-    quarter as follows:
-
-    .. code-block:: python
-
-        transformer = CombineWithReferenceFeature(
-            variables_to_combine=[
-                'number_payments_first_quarter',
-                'number_payments_second_quarter',
-                'number_payments_third_quarter',
-                'number_payments_fourth_quarter',
-            ],
-
-            reference_variables=['total_payments'],
-
-            operations=['div'],
-
-            new_variables_name=[
-                'perc_payments_first_quarter',
-                'perc_payments_second_quarter',
-                'perc_payments_third_quarter',
-                'perc_payments_fourth_quarter',
-            ]
-        )
-
-        Xt = transformer.fit_transform(X)
-
-    The transformed X, Xt, will contain the additional features indicated in the
+    The transformed dataframe will contain the additional features indicated in the
     new_variables_name list plus the original set of variables.
 
+    More details in the :ref:`User Guide <combine_with_ref>`.
+
     Parameters
     ----------
     variables_to_combine: list
-        The list of numerical variables to be combined with the reference
-        variables.
+        The list of numerical variables to combine with the reference variables.
 
     reference_variables: list
         The list of numerical reference variables that will be added to, multiplied
-        with, or subtracted from the variables_to_combine, or used as denominator for
+        with, or subtracted from the `variables_to_combine`, or used as denominator for
         division.
 
     operations: list, default=['sub']
-        The list of basic mathematical operations to be used in transformation.
+        The list of basic mathematical operations to be used in the transformation.
 
-        If None, all of ['sub', 'div','add','mul'] will be performed. Alternatively,
+        If None, all of ['sub', 'div', 'add', 'mul'] will be performed. Alternatively,
         you can enter a list of operations to carry out. Each operation should
-        be a string and must be one of the elements in `['sub', 'div','add', 'mul']`.
+        be a string and must be one of the elements in `['sub', 'div', 'add', 'mul']`.
 
         Each operation will result in a new variable that will be added to the
         transformed dataset.
 
     new_variables_names: list, default=None
-        Names of the newly created variables. You can enter a list with the names for
-        the newly created features (recommended). You must enter as many names as new
-        features created by the transformer. The number of new features is the number
-        of operations times the number of reference variables times the number of
-        variables to combine.
+        Names of the new variables. If passing a list with the names for the new
+        features (recommended), you must enter as many names as new features created
+        by the transformer. The number of new features is the number of `operations`,
+        times the number of `reference_variables`, times the number of
+        `variables_to_combine`.
 
-        Thus, if you want to perform 2 operations, sub and div, combining 4 variables
-        with 2 reference variables, you should enter 2 X 4 X 2 new variable names.
+        If `new_variable_names` is None, the transformer will assign an arbitrary name
+        to the features. The name will be var + operation + ref_var.
 
-        The name of the variables indicated by the user should coincide with the order
-        in which the  operations are performed by the transformer. The transformer will
-        first carry out 'sub', then 'div', then 'add' and finally 'mul'.
-
-        If new_variable_names is None, the transformer will assign an arbitrary name
-        to the newly created features.
-
-    missing_values: string, default='ignore'
-        Indicates if missing values should be ignored or raised. If 'ignore', the
-        transformer will ignore missing data when transforming the data. If 'raise' the
-        transformer will return an error if the training or the datasets to transform
-        contain missing values.
+    {missing_values}
 
+    {drop_original}
 
     Attributes
     ----------
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
-    fit:
-        This transformer does not learn parameters.
+    {fit}
+
     transform:
-        Combine the variables with the mathematical operations.
-    fit_transform:
-        Fit to the data, then transform it.
+        Create new features.
+
+    {fit_transform}
 
     Notes
     -----
     Although the transformer in essence allows us to combine any feature with any of
-    the allowed mathematical operations, its used is intended mostly for the creation
+    the allowed mathematical operations, its use is intended mostly for the creation
     of new features based on some domain knowledge. Typical examples within the
     financial sector are:
 
@@ -134,6 +125,7 @@ class CombineWithReferenceFeature(BaseEstimator, TransformerMixin):
         operations: List[str] = ["sub"],
         new_variables_names: Optional[List[str]] = None,
         missing_values: str = "ignore",
+        drop_original: bool = False,
     ) -> None:
 
         # check input types
@@ -194,15 +186,22 @@ class CombineWithReferenceFeature(BaseEstimator, TransformerMixin):
         if missing_values not in ["raise", "ignore"]:
             raise ValueError("missing_values takes only values 'raise' or 'ignore'")
 
+        if not isinstance(drop_original, bool):
+            raise TypeError(
+                "drop_original takes only boolean values True and False. "
+                f"Got {drop_original} instead."
+            )
+
         self.reference_variables = reference_variables
         self.variables_to_combine = variables_to_combine
         self.new_variables_names = new_variables_names
         self.operations = operations
         self.missing_values = missing_values
+        self.drop_original = drop_original
 
     def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
         """
-        This transformer does not learn any parameter. Performs dataframe checks.
+        This transformer does not learn any parameter.
 
         Parameters
         ----------
@@ -212,23 +211,10 @@ class CombineWithReferenceFeature(BaseEstimator, TransformerMixin):
 
         y: pandas Series, or np.array. Default=None.
             It is not needed in this transformer. You can pass y or None.
-
-        Raises
-        ------
-        TypeError
-           - If the input is not a Pandas DataFrame
-           - If any user provided variables are not numerical
-        ValueError
-           If any of the reference variables contain null values and the
-           mathematical operation is 'div'.
-
-        Returns
-        -------
-        self
         """
 
         # check input dataframe
-        X = _is_dataframe(X)
+        X = check_X(X)
 
         # check variables to combine are numerical
         self.variables_to_combine = _find_or_check_numerical_variables(
@@ -256,6 +242,10 @@ class CombineWithReferenceFeature(BaseEstimator, TransformerMixin):
                     "remove those before using this transformer with div."
                 )
 
+        # save input features
+        self.feature_names_in_ = X.columns.tolist()
+
+        # save train set shape
         self.n_features_in_ = X.shape[1]
 
         return self
@@ -271,18 +261,18 @@ class CombineWithReferenceFeature(BaseEstimator, TransformerMixin):
 
         Returns
         -------
-        X: Pandas dataframe, shape = [n_samples, n_features + n_operations]
-            The dataframe with the operations results added as columns.
+        X_new: Pandas dataframe, shape = [n_samples, n_features + n_operations]
+            The dataframe with the new variables.
         """
 
         # Check method fit has been called
         check_is_fitted(self)
 
         # check that input is a dataframe
-        X = _is_dataframe(X)
+        X = check_X(X)
 
         # Check if input data contains same number of columns as dataframe used to fit.
-        _check_input_matches_training_df(X, self.n_features_in_)
+        _check_X_matches_training_df(X, self.n_features_in_)
 
         # check if dataset contains na
         if self.missing_values == "raise":
@@ -300,7 +290,6 @@ class CombineWithReferenceFeature(BaseEstimator, TransformerMixin):
                     "remove those before using this transformer."
                 )
 
-        original_col_names = [var for var in X.columns]
         # Add new features and values into de data frame.
         if "sub" in self.operations:
             for reference in self.reference_variables:
@@ -333,7 +322,13 @@ class CombineWithReferenceFeature(BaseEstimator, TransformerMixin):
 
         # replace created variable names with user ones.
         if self.new_variables_names:
-            X.columns = original_col_names + self.new_variables_names
+            X.columns = self.feature_names_in_ + self.new_variables_names
+
+        if self.drop_original:
+            X.drop(
+                columns=set(self.variables_to_combine + self.reference_variables),
+                inplace=True,
+            )
 
         return X
 
