@@ -2,102 +2,91 @@ from typing import List, Optional, Union
 
 import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
+from sklearn.utils import deprecated
 from sklearn.utils.validation import check_is_fitted
 
 from feature_engine.dataframe_checks import (
     _check_contains_inf,
     _check_contains_na,
-    _check_input_matches_training_df,
-    _is_dataframe,
+    _check_X_matches_training_df,
+    check_X,
 )
-from feature_engine.validation import _return_tags
+from feature_engine._docstrings.methods import (
+    _fit_not_learn_docstring,
+    _fit_transform_docstring,
+)
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+)
+from feature_engine._docstrings.class_inputs import (
+    _drop_original_docstring,
+    _missing_values_docstring,
+)
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.tags import _return_tags
 from feature_engine.variable_manipulation import _find_or_check_numerical_variables
 
 
+@deprecated(
+    "MathematicalCombination() is deprecated in version 1.3 and will be removed in "
+    "version 1.5. Use MathFeatures() instead."
+)
+@Substitution(
+    missing_values=_missing_values_docstring,
+    drop_original=_drop_original_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    fit=_fit_not_learn_docstring,
+    fit_transform=_fit_transform_docstring,
+)
 class MathematicalCombination(BaseEstimator, TransformerMixin):
     """
+    **DEPRECATED: MathematicalCombination() is deprecated in version 1.3 and will be
+    removed in version 1.5. Use MathFeatures() instead.**
+
     MathematicalCombination() applies basic mathematical operations to multiple
     features, returning one or more additional features as a result. That is, it sums,
     multiplies, takes the average, maximum, minimum or standard deviation of a group
     of variables, and returns the result into new variables.
 
-    For example, if we have the variables **number_payments_first_quarter**,
-    **number_payments_second_quarter**, **number_payments_third_quarter** and
-    **number_payments_fourth_quarter**, we can use MathematicalCombination() to
-    calculate the total number of payments and mean number of payments as follows:
-
-    .. code-block:: python
-
-        transformer = MathematicalCombination(
-            variables_to_combine=[
-                'number_payments_first_quarter',
-                'number_payments_second_quarter',
-                'number_payments_third_quarter',
-                'number_payments_fourth_quarter'
-            ],
-            math_operations=[
-                'sum',
-                'mean'
-            ],
-            new_variables_name=[
-                'total_number_payments',
-                'mean_number_payments'
-            ]
-        )
-
-        Xt = transformer.fit_transform(X)
-
-    The transformed X, Xt, will contain the additional features
-    **total_number_payments** and **mean_number_payments**, plus the original set of
-    variables.
-
-    Attention, if some of the variables to combine have missing data and
-    `missing_values = 'ignore'`, the value will be ignored in the computation. To be
+    Note that if some of the variables to combine have missing data and you set
+    `missing_values='ignore'`, the value will be ignored in the computation. To be
     clear, if variables A, B and C, have values 10, 20 and NA, and we perform the sum,
     the result will be A + B = 30.
 
+    More details in the :ref:`User Guide <math_combination>`.
+
     Parameters
     ----------
     variables_to_combine: list
-        The list of numerical variables to be combined.
+        The list of numerical variables to combine.
 
     math_operations: list, default=None
         The list of basic math operations to be used to create the new features.
 
-        If None, all of ['sum', 'prod', 'mean', 'std', 'max', 'min'] will be performed
-        over the `variables_to_combine`. Alternatively, you can enter the list of
-        operations to carry out.
-
-        Each operation should be a string and must be one of the elements
-        in `['sum', 'prod', 'mean', 'std', 'max', 'min']`.
+        If None, all of ['sum', 'prod', 'mean', 'std', 'max', 'min'] will be performed.
+        Alternatively, you can enter the list of operations to carry out. Each operation
+        should be a string and must be one of the elements in
+        `['sum', 'prod', 'mean', 'std', 'max', 'min']`.
 
         Each operation will result in a new variable that will be added to the
         transformed dataset.
 
     new_variables_names: list, default=None
-        Names of the newly created variables. You can enter a name or a list
-        of names for the newly created features (recommended). You must enter
-        one name for each mathematical transformation indicated in the `math_operations`
-        parameter. That is, if you want to perform mean and sum of features, you
-        should enter 2 new variable names. If you perform only mean of features,
-        enter 1 variable name. Alternatively, if you chose to perform all
-        mathematical transformations, enter 6 new variable names.
-
-        The name of the variables indicated by the user should coincide with the order
-        in which the mathematical operations are initialised in the transformer.
-        That is, if you set math_operations = ['mean', 'prod'], the first new variable
-        name will be assigned to the mean of the variables and the second variable name
-        to the product of the variables.
+        Names of the new variables. If passing a list with the names for the new
+        features (recommended), you must enter one name for each mathematical
+        transformation indicated in the `math_operations` parameter. The name of the
+        new variables should coincide with the order in which the mathematical
+        operations are initialised in the transformer.
 
         If `new_variable_names = None`, the transformer will assign an arbitrary name
         to the newly created features starting by the name of the mathematical
         operation, followed by the variables combined separated by -.
 
-    missing_values: string, default='raise'
-        Indicates if missing values should be ignored or raised. If 'raise' the
-        transformer will return an error if the the datasets to fit or transform
-        contain missing values. If 'ignore', missing data will be ignored when
-        performing the calculations.
+    {missing_values}
+
+    {drop_original}
 
     Attributes
     ----------
@@ -108,17 +97,18 @@ class MathematicalCombination(BaseEstimator, TransformerMixin):
         List with the mathematical operations to be applied to the
         `variables_to_combine`.
 
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
-    fit:
-        This transformer does not learn parameters.
+    {fit}
+
     transform:
-        Combine the variables with the mathematical operations.
-    fit_transform:
-        Fit to the data, then transform it.
+        Create new features.
+
+    {fit_transform}
 
     Notes
     -----
@@ -141,6 +131,7 @@ class MathematicalCombination(BaseEstimator, TransformerMixin):
         math_operations: Optional[List[str]] = None,
         new_variables_names: Optional[List[str]] = None,
         missing_values: str = "raise",
+        drop_original: bool = False,
     ) -> None:
 
         # check input types
@@ -196,10 +187,17 @@ class MathematicalCombination(BaseEstimator, TransformerMixin):
                     "combine."
                 )
 
+        if not isinstance(drop_original, bool):
+            raise TypeError(
+                "drop_original takes only boolean values True and False. "
+                f"Got {drop_original} instead."
+            )
+
         self.variables_to_combine = variables_to_combine
         self.new_variables_names = new_variables_names
         self.math_operations = math_operations
         self.missing_values = missing_values
+        self.drop_original = drop_original
 
     def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
         """
@@ -216,22 +214,10 @@ class MathematicalCombination(BaseEstimator, TransformerMixin):
 
         y: pandas Series, or np.array. Defaults to None.
             It is not needed in this transformer. You can pass y or None.
-
-        Raises
-        ------
-        TypeError
-           - If the input is not a Pandas DataFrame
-           - If any user provided variables in variables_to_combine are not numerical
-        ValueError
-           If the variable(s) contain null values when missing_values = raise
-
-        Returns
-        -------
-        self
         """
 
         # check input dataframe
-        X = _is_dataframe(X)
+        X = check_X(X)
 
         # check variables to combine are numerical
         self.variables_to_combine = _find_or_check_numerical_variables(
@@ -264,6 +250,10 @@ class MathematicalCombination(BaseEstimator, TransformerMixin):
                 for operation in self.math_operations_
             }
 
+        # save input features
+        self.feature_names_in_ = X.columns.tolist()
+
+        # save train set shape
         self.n_features_in_ = X.shape[1]
 
         return self
@@ -277,17 +267,9 @@ class MathematicalCombination(BaseEstimator, TransformerMixin):
         X: pandas dataframe of shape = [n_samples, n_features]
             The data to transform.
 
-        Raises
-        ------
-        TypeError
-           If the input is not a Pandas DataFrame
-        ValueError
-           - If the variable(s) contain null values when missing_values = raise
-           - If the dataframe is not of the same size as that used in fit()
-
         Returns
         -------
-        X: Pandas dataframe, shape = [n_samples, n_features + n_operations]
+        X_new: Pandas dataframe, shape = [n_samples, n_features + n_operations]
             The dataframe with the original variables plus the new variables.
         """
 
@@ -295,10 +277,10 @@ class MathematicalCombination(BaseEstimator, TransformerMixin):
         check_is_fitted(self)
 
         # check that input is a dataframe
-        X = _is_dataframe(X)
+        X = check_X(X)
 
         # Check if input data contains same number of columns as dataframe used to fit.
-        _check_input_matches_training_df(X, self.n_features_in_)
+        _check_X_matches_training_df(X, self.n_features_in_)
 
         # check if dataset contains na
         if self.missing_values == "raise":
@@ -309,6 +291,9 @@ class MathematicalCombination(BaseEstimator, TransformerMixin):
         for new_variable_name, operation in self.combination_dict_.items():
             X[new_variable_name] = X[self.variables_to_combine].agg(operation, axis=1)
 
+        if self.drop_original:
+            X.drop(columns=self.variables_to_combine, inplace=True)
+
         return X
 
     def _more_tags(self):
