@@ -1,29 +1,109 @@
 import warnings
-from typing import List, Union
+from typing import List, Optional, Union
 
 import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.utils.validation import check_is_fitted
 
+from feature_engine._docstrings.methods import _get_feature_names_out_docstring
+from feature_engine._docstrings.substitute import Substitution
 from feature_engine.dataframe_checks import (
     _check_contains_na,
-    _check_input_matches_training_df,
-    _is_dataframe,
+    _check_X_matches_training_df,
+    check_X,
 )
-from feature_engine.validation import _return_tags
+from feature_engine.encoding._docstrings import (
+    _errors_docstring,
+    _ignore_format_docstring,
+    _variables_docstring,
+)
+from feature_engine.get_feature_names_out import _get_feature_names_out
+from feature_engine.tags import _return_tags
 from feature_engine.variable_manipulation import (
+    _check_input_parameter_variables,
     _find_all_variables,
     _find_or_check_categorical_variables,
 )
 
 
-class BaseCategoricalTransformer(BaseEstimator, TransformerMixin):
-    """shared set-up checks and methods across categorical transformers"""
+@Substitution(
+    ignore_format=_ignore_format_docstring,
+    variables=_variables_docstring,
+)
+class CategoricalInitMixin:
+    """Shared initialization parameters across transformers.
 
-    def _check_fit_input_and_variables(self, X: pd.DataFrame) -> pd.DataFrame:
+    Parameters
+    ----------
+    {variables}.
+
+    {ignore_format}
+    """
+
+    def __init__(
+        self,
+        variables: Union[None, int, str, List[Union[str, int]]] = None,
+        ignore_format: bool = False,
+    ) -> None:
+
+        if not isinstance(ignore_format, bool):
+            raise ValueError(
+                "ignore_format takes only booleans True and False. "
+                f"Got {ignore_format} instead."
+            )
+
+        self.variables = _check_input_parameter_variables(variables)
+        self.ignore_format = ignore_format
+
+
+@Substitution(
+    ignore_format=_ignore_format_docstring,
+    variables=_variables_docstring,
+    errors=_errors_docstring,
+)
+class CategoricalInitExpandedMixin(CategoricalInitMixin):
+    """Shared initialization parameters across transformers. Contains additional
+    initialization parameters respect to the parent class.
+
+    Parameters
+    ----------
+    {variables}.
+
+    {ignore_format}
+
+    {errors}
+    """
+
+    def __init__(
+        self,
+        variables: Union[None, int, str, List[Union[str, int]]] = None,
+        ignore_format: bool = False,
+        errors: str = "ignore",
+    ) -> None:
+        if errors not in ["raise", "ignore"]:
+            raise ValueError(
+                "errors takes only values 'raise' and 'ignore ."
+                f"Got {errors} instead."
+            )
+
+        super().__init__(variables, ignore_format)
+        self.errors = errors
+
+
+@Substitution(
+    ignore_format=_ignore_format_docstring,
+    variables=_variables_docstring,
+)
+class CategoricalMethodsMixin(BaseEstimator, TransformerMixin):
+    """Shared methods across categorical transformers.
+    BaseEstimator brings methods get_params() and set_params().
+    TransformerMixin brings method fit_transform()
+    """
+
+    def _check_or_select_variables(self, X: pd.DataFrame):
         """
-        Checks that input is a dataframe, finds categorical variables, or alternatively
-        checks that the variables entered by the user are of type object (categorical).
+        Finds categorical variables, or alternatively checks that the variables
+        entered by the user are of type object (categorical).
         Checks absence of NA.
 
         Parameters
@@ -33,23 +113,11 @@ class BaseCategoricalTransformer(BaseEstimator, TransformerMixin):
         Raises
         ------
         TypeError
-            If the input is not a Pandas DataFrame.
             If any user provided variable is not categorical
         ValueError
             If there are no categorical variables in the df or the df is empty
             If the variable(s) contain null values
-
-        Returns
-        -------
-        X: Pandas DataFrame
-            The same dataframe entered as parameter
-        variables : list
-            list of categorical variables
         """
-
-        # check input dataframe
-        X = _is_dataframe(X)
-
         if not self.ignore_format:
             # find categorical variables or check variables entered by user are object
             self.variables_: List[
@@ -62,7 +130,13 @@ class BaseCategoricalTransformer(BaseEstimator, TransformerMixin):
         # check if dataset contains na
         _check_contains_na(X, self.variables_)
 
-        return X
+    def _get_feature_names_in(self, X: pd.DataFrame):
+
+        # save input features
+        self.feature_names_in_ = X.columns.tolist()
+
+        # save train set shape
+        self.n_features_in_ = X.shape[1]
 
     def _check_transform_input_and_state(self, X: pd.DataFrame) -> pd.DataFrame:
         """
@@ -91,14 +165,17 @@ class BaseCategoricalTransformer(BaseEstimator, TransformerMixin):
         check_is_fitted(self)
 
         # check that input is a dataframe
-        X = _is_dataframe(X)
+        X = check_X(X)
 
         # Check input data contains same number of columns as df used to fit
-        _check_input_matches_training_df(X, self.n_features_in_)
+        _check_X_matches_training_df(X, self.n_features_in_)
 
         # check if dataset contains na
         _check_contains_na(X, self.variables_)
 
+        # reorder df to match train set
+        X = X[self.feature_names_in_]
+
         return X
 
     def _check_encoding_dictionary(self):
@@ -122,19 +199,9 @@ class BaseCategoricalTransformer(BaseEstimator, TransformerMixin):
         X: pandas dataframe of shape = [n_samples, n_features].
             The dataset to transform.
 
-        Raises
-        ------
-        TypeError
-            If the input is not a Pandas DataFrame
-        ValueError
-            - If the variable(s) contain null values
-            - If the df has different number of features than the df used in fit()
-        Warning
-            If after encoding, NAN were introduced.
-
         Returns
         -------
-        X: pandas dataframe of shape = [n_samples, n_features].
+        X_new: pandas dataframe of shape = [n_samples, n_features].
             The dataframe containing the categories replaced by numbers.
         """
 
@@ -154,15 +221,30 @@ class BaseCategoricalTransformer(BaseEstimator, TransformerMixin):
 
         # check if NaN values were introduced by the encoding
         if X[self.encoder_dict_.keys()].isnull().sum().sum() > 0:
-            warnings.warn(
-                "NaN values were introduced in the returned dataframe by the encoder."
-                "This means that some of the categories in the input dataframe were "
-                "not present in the training set used when the fit method was called. "
-                "Thus, mappings for those categories do not exist. Try using the "
-                "RareLabelCategoricalEncoder to remove infrequent categories before "
-                "calling this encoder."
+
+            # obtain the name(s) of the columns have null values
+            nan_columns = (
+                X[self.encoder_dict_.keys()]
+                .columns[X[self.encoder_dict_.keys()].isnull().any()]
+                .tolist()
             )
 
+            if len(nan_columns) > 1:
+                nan_columns_str = ", ".join(nan_columns)
+            else:
+                nan_columns_str = nan_columns[0]
+
+            if self.errors == "ignore":
+                warnings.warn(
+                    "During the encoding, NaN values were introduced in the feature(s) "
+                    f"{nan_columns_str}."
+                )
+            elif self.errors == "raise":
+                raise ValueError(
+                    "During the encoding, NaN values were introduced in the feature(s) "
+                    f"{nan_columns_str}."
+                )
+
         return X
 
     def inverse_transform(self, X: pd.DataFrame) -> pd.DataFrame:
@@ -173,17 +255,9 @@ class BaseCategoricalTransformer(BaseEstimator, TransformerMixin):
         X: pandas dataframe of shape = [n_samples, n_features].
             The transformed dataframe.
 
-        Raises
-        ------
-        TypeError
-            If the input is not a Pandas DataFrame
-        ValueError
-            - If the variable(s) contain null values
-            - If the df has different number of features than the df used in fit()
-
         Returns
         -------
-        X: pandas dataframe of shape = [n_samples, n_features].
+        X_tr: pandas dataframe of shape = [n_samples, n_features].
             The un-transformed dataframe, with the categorical variables containing the
             original values.
         """
@@ -197,8 +271,25 @@ class BaseCategoricalTransformer(BaseEstimator, TransformerMixin):
 
         return X
 
+    @Substitution(get_feature_names_out=_get_feature_names_out_docstring)
+    def get_feature_names_out(
+        self, input_features: Optional[List[Union[str, int]]] = None
+    ) -> List[Union[str, int]]:
+        """{get_feature_names_out}"""
+
+        check_is_fitted(self)
+
+        feature_names = _get_feature_names_out(
+            features_in=self.feature_names_in_,
+            transformed_features=self.variables_,
+            input_features=input_features,
+        )
+
+        return feature_names
+
     def _more_tags(self):
         tags_dict = _return_tags()
+        tags_dict["variables"] = "categorical"
         # the below test will fail because sklearn requires to check for inf, but
         # you can't check inf of categorical data, numpy returns and error.
         # so we need to leave without this test
