@@ -5,23 +5,46 @@ from typing import List, Optional, Union
 
 import pandas as pd
 
-from feature_engine.encoding.base_encoder import BaseCategoricalTransformer
-from feature_engine.variable_manipulation import _check_input_parameter_variables
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+    _variables_attribute_docstring,
+)
+from feature_engine._docstrings.methods import (
+    _fit_transform_docstring,
+    _inverse_transform_docstring,
+)
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.dataframe_checks import check_X, check_X_y
+from feature_engine.encoding._docstrings import (
+    _errors_docstring,
+    _ignore_format_docstring,
+    _transform_docstring,
+    _variables_docstring,
+)
+from feature_engine.encoding.base_encoder import (
+    CategoricalInitExpandedMixin,
+    CategoricalMethodsMixin,
+)
 
 
-class OrdinalEncoder(BaseCategoricalTransformer):
+@Substitution(
+    ignore_format=_ignore_format_docstring,
+    variables=_variables_docstring,
+    errors=_errors_docstring,
+    variables_=_variables_attribute_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    fit_transform=_fit_transform_docstring,
+    transform=_transform_docstring,
+    inverse_transform=_inverse_transform_docstring,
+)
+class OrdinalEncoder(CategoricalInitExpandedMixin, CategoricalMethodsMixin):
     """
-    The OrdinalCategoricalEncoder() replaces categories by ordinal numbers
+    The OrdinalEncoder() replaces categories by ordinal numbers
     (0, 1, 2, 3, etc). The numbers can be ordered based on the mean of the target
     per category, or assigned arbitrarily.
 
-    **Ordered ordinal encoding**: for the variable colour, if the mean of the target
-    for blue, red and grey is 0.5, 0.8 and 0.1 respectively, blue is replaced by 1,
-    red by 2 and grey by 0.
-
-    **Arbitrary ordinal encoding**: the numbers will be assigned arbitrarily to the
-    categories, on a first seen first served basis.
-
     The encoder will encode only categorical variables by default (type 'object' or
     'categorical'). You can pass a list of variables to encode. Alternatively, the
     encoder will find and encode all categorical variables (type 'object' or
@@ -34,50 +57,45 @@ class OrdinalEncoder(BaseCategoricalTransformer):
     The encoder first maps the categories to the numbers for each variable (fit). The
     encoder then transforms the categories to the mapped numbers (transform).
 
+    More details in the :ref:`User Guide <ordinal_encoder>`.
+
     Parameters
     ----------
     encoding_method: str, default='ordered'
         Desired method of encoding.
 
-        'ordered': the categories are numbered in ascending order according to
+        **'ordered'**: the categories are numbered in ascending order according to
         the target mean value per category.
 
-        'arbitrary' : categories are numbered arbitrarily.
+        **'arbitrary'**: categories are numbered arbitrarily.
 
-    variables: list, default=None
-        The list of categorical variables that will be encoded. If None, the
-        encoder will find and transform all variables of type object or categorical by
-        default. You can also make the transformer accept numerical variables, see the
-        next parameter.
+    {variables}
 
-    ignore_format: bool, default=False
-        Whether the format in which the categorical variables are cast should be
-        ignored. If false, the encoder will automatically select variables of type
-        object or categorical, or check that the variables entered by the user are of
-        type object or categorical. If True, the encoder will select all variables or
-        accept all variables entered by the user, including those cast as numeric.
+    {ignore_format}
+
+    {errors}
 
     Attributes
     ----------
     encoder_dict_:
         Dictionary with the ordinal number per category, per variable.
 
-    variables_:
-        The group of variables that will be transformed.
+    {variables_}
 
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
     fit:
         Find the integer to replace each category in each variable.
-    transform:
-        Encode the categories to numbers.
-    fit_transform:
-        Fit to the data, then transform it.
-    inverse_transform:
-        Encode the numbers into the original categories.
+
+    {fit_transform}
+
+    {inverse_transform}
+
+    {transform}
 
     Notes
     -----
@@ -85,9 +103,13 @@ class OrdinalEncoder(BaseCategoricalTransformer):
     dataset. If this happens, try grouping infrequent categories using the
     RareLabelEncoder().
 
+    There is a similar implementation in the the open-source package
+    `Category encoders <https://contrib.scikit-learn.org/category_encoders/>`_
+
     See Also
     --------
     feature_engine.encoding.RareLabelEncoder
+    category_encoders.ordinal.OrdinalEncoder
 
     References
     ----------
@@ -103,6 +125,7 @@ class OrdinalEncoder(BaseCategoricalTransformer):
         encoding_method: str = "ordered",
         variables: Union[None, int, str, List[Union[str, int]]] = None,
         ignore_format: bool = False,
+        errors: str = "ignore",
     ) -> None:
 
         if encoding_method not in ["ordered", "arbitrary"]:
@@ -110,12 +133,9 @@ class OrdinalEncoder(BaseCategoricalTransformer):
                 "encoding_method takes only values 'ordered' and 'arbitrary'"
             )
 
-        if not isinstance(ignore_format, bool):
-            raise ValueError("ignore_format takes only booleans True and False")
+        super().__init__(variables, ignore_format, errors)
 
         self.encoding_method = encoding_method
-        self.variables = _check_input_parameter_variables(variables)
-        self.ignore_format = ignore_format
 
     def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
         """Learn the numbers to be used to replace the categories in each
@@ -128,33 +148,19 @@ class OrdinalEncoder(BaseCategoricalTransformer):
             variables to be encoded.
 
         y: pandas series, default=None
-            The Target. Can be None if encoding_method = 'arbitrary'.
+            The Target. Can be None if `encoding_method='arbitrary'`.
             Otherwise, y needs to be passed when fitting the transformer.
-
-        Raises
-        ------
-        TypeError
-            - If the input is not a Pandas DataFrame.
-            - If user enters non-categorical variables (unless ignore_format is True)
-        ValueError
-            - If there are no categorical variables in the df or the df is empty
-            - If the variable(s) contain null values
-
-        Returns
-        -------
-        self
         """
 
-        X = self._check_fit_input_and_variables(X)
-
-        # join target to predictor variables
         if self.encoding_method == "ordered":
-            if y is None:
-                raise ValueError("Please provide a target y for this encoding method")
+            X, y = check_X_y(X, y)
+        else:
+            X = check_X(X)
 
-            if not isinstance(y, pd.Series):
-                y = pd.Series(y)
+        self._check_or_select_variables(X)
+        self._get_feature_names_in(X)
 
+        if self.encoding_method == "ordered":
             temp = pd.concat([X, y], axis=1)
             temp.columns = list(X.columns) + ["target"]
 
@@ -178,21 +184,4 @@ class OrdinalEncoder(BaseCategoricalTransformer):
 
         self._check_encoding_dictionary()
 
-        self.n_features_in_ = X.shape[1]
-
         return self
-
-    # Ugly work around to import the docstring for Sphinx, otherwise not necessary
-    def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        X = super().transform(X)
-
-        return X
-
-    transform.__doc__ = BaseCategoricalTransformer.transform.__doc__
-
-    def inverse_transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        X = super().inverse_transform(X)
-
-        return X
-
-    inverse_transform.__doc__ = BaseCategoricalTransformer.inverse_transform.__doc__
