@@ -6,12 +6,42 @@ from typing import List, Union
 import numpy as np
 import pandas as pd
 
-from feature_engine.encoding.base_encoder import BaseCategoricalTransformer
-from feature_engine.validation import _return_tags
-from feature_engine.variable_manipulation import _check_input_parameter_variables
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+    _variables_attribute_docstring,
+)
+from feature_engine._docstrings.methods import (
+    _fit_transform_docstring,
+    _inverse_transform_docstring,
+)
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.dataframe_checks import check_X_y
+from feature_engine.encoding._docstrings import (
+    _errors_docstring,
+    _ignore_format_docstring,
+    _transform_docstring,
+    _variables_docstring,
+)
+from feature_engine.encoding.base_encoder import (
+    CategoricalInitExpandedMixin,
+    CategoricalMethodsMixin,
+)
+from feature_engine.tags import _return_tags
 
 
-class PRatioEncoder(BaseCategoricalTransformer):
+@Substitution(
+    ignore_format=_ignore_format_docstring,
+    variables=_variables_docstring,
+    errors=_errors_docstring,
+    variables_=_variables_attribute_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    fit_transform=_fit_transform_docstring,
+    transform=_transform_docstring,
+    inverse_transform=_inverse_transform_docstring,
+)
+class PRatioEncoder(CategoricalInitExpandedMixin, CategoricalMethodsMixin):
     """
     The PRatioEncoder() replaces categories by the ratio of the probability of the
     target = 1 and the probability of the target = 0.
@@ -32,12 +62,7 @@ class PRatioEncoder(BaseCategoricalTransformer):
 
     This categorical encoding is exclusive for binary classification.
 
-    For example in the variable colour, if the mean of the target = 1 for blue
-    is 0.8 and the mean of the target = 0  is 0.2, blue will be replaced by:
-    0.8 / 0.2 = 4 if ratio is selected, or log(0.8/0.2) = 1.386 if log_ratio
-    is selected.
-
-    Note: the division by 0 is not defined and the log(0) is not defined.
+    The division by 0 is not defined and the log(0) is not defined.
     Thus, if p(0) = 0 for the ratio encoder, or either p(0) = 0 or p(1) = 0 for
     log_ratio, in any of the variables, the encoder will return an error.
 
@@ -53,49 +78,44 @@ class PRatioEncoder(BaseCategoricalTransformer):
     The encoder first maps the categories to the numbers for each variable (fit). The
     encoder then transforms the categories into the mapped numbers (transform).
 
+    More details in the :ref:`User Guide <pratio_encoder>`.
+
     Parameters
     ----------
     encoding_method: str, default='ratio'
         Desired method of encoding.
 
-        'ratio' : probability ratio
+        **'ratio'**: probability ratio
 
-        'log_ratio' : log probability ratio
+        **'log_ratio'**: log probability ratio
 
-    variables: list, default=None
-        The list of categorical variables that will be encoded. If None, the
-        encoder will find and transform all variables of type object or categorical by
-        default. You can also make the transformer accept numerical variables, see the
-        next parameter.
+    {variables}
 
-    ignore_format: bool, default=False
-        Whether the format in which the categorical variables are cast should be
-        ignored. If false, the encoder will automatically select variables of type
-        object or categorical, or check that the variables entered by the user are of
-        type object or categorical. If True, the encoder will select all variables or
-        accept all variables entered by the user, including those cast as numeric.
+    {ignore_format}
+
+    {errors}
 
     Attributes
     ----------
     encoder_dict_:
         Dictionary with the probability ratio per category per variable.
 
-    variables_:
-        The group of variables that will be transformed.
+    {variables_}
 
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
     fit:
         Learn probability ratio per category, per variable.
-    transform:
-        Encode categories into numbers.
-    fit_transform:
-        Fit to the data, then transform it.
-    inverse_transform:
-        Encode the numbers into the original categories.
+
+    {fit_transform}
+
+    {inverse_transform}
+
+    {transform}
 
     Notes
     -----
@@ -113,6 +133,7 @@ class PRatioEncoder(BaseCategoricalTransformer):
         encoding_method: str = "ratio",
         variables: Union[None, int, str, List[Union[str, int]]] = None,
         ignore_format: bool = False,
+        errors: str = "ignore",
     ) -> None:
 
         if encoding_method not in ["ratio", "log_ratio"]:
@@ -120,12 +141,9 @@ class PRatioEncoder(BaseCategoricalTransformer):
                 "encoding_method takes only values 'ratio' and 'log_ratio'"
             )
 
-        if not isinstance(ignore_format, bool):
-            raise ValueError("ignore_format takes only booleans True and False")
+        super().__init__(variables, ignore_format, errors)
 
         self.encoding_method = encoding_method
-        self.variables = _check_input_parameter_variables(variables)
-        self.ignore_format = ignore_format
 
     def fit(self, X: pd.DataFrame, y: pd.Series):
         """
@@ -140,27 +158,9 @@ class PRatioEncoder(BaseCategoricalTransformer):
 
         y: pandas series.
             Target, must be binary.
-
-        Raises
-        ------
-        TypeError
-            - If the input is not the Pandas DataFrame.
-            - If user enters non-categorical variables (unless ignore_format is True)
-        ValueError
-            - If there are no categorical variables in df or df is empty
-            - If variable(s) contain null values.
-            - If y is not binary with values 0 and 1.
-            - If p(0) = 0 or any of p(0) or p(1) are 0.
-
-        Returns
-        -------
-        self
         """
 
-        X = self._check_fit_input_and_variables(X)
-
-        if not isinstance(y, pd.Series):
-            y = pd.Series(y)
+        X, y = check_X_y(X, y)
 
         # check that y is binary
         if y.nunique() != 2:
@@ -169,6 +169,9 @@ class PRatioEncoder(BaseCategoricalTransformer):
                 "used has more than 2 unique values."
             )
 
+        self._check_or_select_variables(X)
+        self._get_feature_names_in(X)
+
         temp = pd.concat([X, y], axis=1)
         temp.columns = list(X.columns) + ["target"]
 
@@ -206,27 +209,12 @@ class PRatioEncoder(BaseCategoricalTransformer):
 
         self._check_encoding_dictionary()
 
-        self.n_features_in_ = X.shape[1]
-
         return self
 
-    # Ugly work around to import the docstring for Sphinx, otherwise not necessary
-    def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        X = super().transform(X)
-
-        return X
-
-    transform.__doc__ = BaseCategoricalTransformer.transform.__doc__
-
-    def inverse_transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        X = super().inverse_transform(X)
-
-        return X
-
-    inverse_transform.__doc__ = BaseCategoricalTransformer.inverse_transform.__doc__
-
     def _more_tags(self):
         tags_dict = _return_tags()
+        tags_dict["variables"] = "categorical"
+        tags_dict["requires_y"] = True
         # in the current format, the tests are performed using continuous np.arrays
         # this means that when we encode some of the values, the denominator is 0
         # and this the transformer raises an error, and the test fails.
