@@ -6,14 +6,44 @@ from typing import List, Union
 import numpy as np
 import pandas as pd
 
-from feature_engine.encoding.base_encoder import BaseCategoricalTransformer
-from feature_engine.validation import _return_tags
-from feature_engine.variable_manipulation import _check_input_parameter_variables
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+    _variables_attribute_docstring,
+)
+from feature_engine._docstrings.methods import (
+    _fit_transform_docstring,
+    _inverse_transform_docstring,
+)
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.dataframe_checks import check_X_y
+from feature_engine.encoding._docstrings import (
+    _errors_docstring,
+    _ignore_format_docstring,
+    _transform_docstring,
+    _variables_docstring,
+)
+from feature_engine.encoding.base_encoder import (
+    CategoricalInitExpandedMixin,
+    CategoricalMethodsMixin,
+)
+from feature_engine.tags import _return_tags
 
 
-class WoEEncoder(BaseCategoricalTransformer):
+@Substitution(
+    ignore_format=_ignore_format_docstring,
+    variables=_variables_docstring,
+    errors=_errors_docstring,
+    variables_=_variables_attribute_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    fit_transform=_fit_transform_docstring,
+    transform=_transform_docstring,
+    inverse_transform=_inverse_transform_docstring,
+)
+class WoEEncoder(CategoricalInitExpandedMixin, CategoricalMethodsMixin):
     """
-    The WoERatioCategoricalEncoder() replaces categories by the weight of evidence
+    The WoEEncoder() replaces categories by the weight of evidence
     (WoE). The WoE was used primarily in the financial sector to create credit risk
     scorecards.
 
@@ -30,115 +60,73 @@ class WoEEncoder(BaseCategoricalTransformer):
     (fit). The encoder then transforms the categories into the mapped numbers
     (transform).
 
-    **Note**
-
     This categorical encoding is exclusive for binary classification.
 
-    **The weight of evidence is given by:**
-
-    .. math::
-
-        log( p(X=xj|Y = 1) / p(X=xj|Y=0) )
-
-
-
-    **The WoE is determined as follows:**
-
-    We calculate the percentage positive cases in each category of the total of all
-    positive cases. For example 20 positive cases in category A out of 100 total
-    positive cases equals 20 %. Next, we calculate the percentage of negative cases in
-    each category respect to the total negative cases, for example 5 negative cases in
-    category A out of a total of 50 negative cases equals 10%. Then we calculate the
-    WoE by dividing the category percentages of positive cases by the category
-    percentage of negative cases, and take the logarithm, so for category A in our
-    example WoE = log(20/10).
-
-    **Note**
-
-    - If WoE values are negative, negative cases supersede the positive cases.
-    - If WoE values are positive, positive cases supersede the negative cases.
-    - And if WoE is 0, then there are equal number of positive and negative examples.
-
-    **Encoding into WoE**:
-
-    - Creates a monotonic relationship between the encoded variable and the target
-    - Returns variables in a similar scale
-
     **Note**
 
     The log(0) is not defined and the division by 0 is not defined. Thus, if any of the
     terms in the WoE equation are 0 for a given category, the encoder will return an
     error. If this happens, try grouping less frequent categories.
 
+    More details in the :ref:`User Guide <woe_encoder>`.
+
     Parameters
     ----------
-    variables: list, default=None
-        The list of categorical variables that will be encoded. If None, the
-        encoder will find and transform all variables of type object or categorical by
-        default. You can also make the transformer accept numerical variables, see the
-        next parameter.
+    {variables}
 
-    ignore_format: bool, default=False
-        Whether the format in which the categorical variables are cast should be
-        ignored. If false, the encoder will automatically select variables of type
-        object or categorical, or check that the variables entered by the user are of
-        type object or categorical. If True, the encoder will select all variables or
-        accept all variables entered by the user, including those cast as numeric.
+    {ignore_format}
+
+    {errors}
 
     Attributes
     ----------
     encoder_dict_:
         Dictionary with the WoE per variable.
 
-    variables_:
-        The group of variables that will be transformed.
+    {variables_}
 
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
     fit:
         Learn the WoE per category, per variable.
-    transform:
-        Encode the categories to numbers.
-    fit_transform:
-        Fit to the data, then transform it.
-    inverse_transform:
-        Encode the numbers into the original categories.
+
+    {transform}
+
+    {fit_transform}
+
+    {inverse_transform}
 
     Notes
     -----
     For details on the calculation of the weight of evidence visit:
     https://www.listendata.com/2015/03/weight-of-evidence-woe-and-information.html
 
-    In credit scoring, continuous variables are also transformed using the WoE. To do
-    this, first variables are sorted into a discrete number of bins, and then these
-    bins are encoded with the WoE as explained here for categorical variables. You can
-    do this by combining the use of the equal width, equal frequency or arbitrary
-    discretisers.
-
     NAN are introduced when encoding categories that were not present in the training
     dataset. If this happens, try grouping infrequent categories using the
     RareLabelEncoder().
 
+    There is a similar implementation in the the open-source package
+    `Category encoders <https://contrib.scikit-learn.org/category_encoders/>`_
+
     See Also
     --------
     feature_engine.encoding.RareLabelEncoder
     feature_engine.discretisation
+    category_encoders.woe.WOEEncoder
     """
 
     def __init__(
         self,
         variables: Union[None, int, str, List[Union[str, int]]] = None,
         ignore_format: bool = False,
+        errors: str = "ignore",
     ) -> None:
 
-        if not isinstance(ignore_format, bool):
-            raise ValueError("ignore_format takes only booleans True and False")
-
-        self.variables = _check_input_parameter_variables(variables)
-        self.ignore_format = ignore_format
+        super().__init__(variables, ignore_format, errors)
 
     def fit(self, X: pd.DataFrame, y: pd.Series):
         """
@@ -152,27 +140,9 @@ class WoEEncoder(BaseCategoricalTransformer):
 
         y: pandas series.
             Target, must be binary.
-
-        Raises
-        ------
-        TypeError
-            - If the input is not the Pandas DataFrame.
-            - If user enters non-categorical variables (unless ignore_format is True)
-        ValueError
-            - If there are no categorical variables in df or df is empty
-            - If variable(s) contain null values.
-            - If y is not binary with values 0 and 1.
-            - If p(0) = 0 or p(1) = 0.
-
-        Returns
-        -------
-        self
         """
 
-        X = self._check_fit_input_and_variables(X)
-
-        if not isinstance(y, pd.Series):
-            y = pd.Series(y)
+        X, y = check_X_y(X, y)
 
         # check that y is binary
         if y.nunique() != 2:
@@ -181,6 +151,9 @@ class WoEEncoder(BaseCategoricalTransformer):
                 "used has more than 2 unique values."
             )
 
+        self._check_or_select_variables(X)
+        self._get_feature_names_in(X)
+
         temp = pd.concat([X, y], axis=1)
         temp.columns = list(X.columns) + ["target"]
 
@@ -215,27 +188,12 @@ class WoEEncoder(BaseCategoricalTransformer):
 
         self._check_encoding_dictionary()
 
-        self.n_features_in_ = X.shape[1]
-
         return self
 
-    # Ugly work around to import the docstring for Sphinx, otherwise not necessary
-    def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        X = super().transform(X)
-
-        return X
-
-    transform.__doc__ = BaseCategoricalTransformer.transform.__doc__
-
-    def inverse_transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        X = super().inverse_transform(X)
-
-        return X
-
-    inverse_transform.__doc__ = BaseCategoricalTransformer.inverse_transform.__doc__
-
     def _more_tags(self):
         tags_dict = _return_tags()
+        tags_dict["variables"] = "categorical"
+        tags_dict["requires_y"] = True
         # in the current format, the tests are performed using continuous np.arrays
         # this means that when we encode some of the values, the denominator is 0
         # and this the transformer raises an error, and the test fails.
