@@ -5,8 +5,16 @@ from typing import List, Optional, Union
 
 import pandas as pd
 
-from feature_engine.dataframe_checks import _is_dataframe
+from feature_engine.dataframe_checks import check_X
+from feature_engine._docstrings.methods import _fit_transform_docstring
+from feature_engine._docstrings.fit_attributes import (
+    _variables_attribute_docstring,
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+)
+from feature_engine._docstrings.substitute import Substitution
 from feature_engine.imputation.base_imputer import BaseImputer
+from feature_engine.tags import _return_tags
 from feature_engine.variable_manipulation import (
     _check_input_parameter_variables,
     _find_all_variables,
@@ -14,25 +22,35 @@ from feature_engine.variable_manipulation import (
 )
 
 
+@Substitution(
+    imputer_dict_=BaseImputer._imputer_dict_docstring,
+    variables_=_variables_attribute_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    transform=BaseImputer._transform_docstring,
+    fit_transform=_fit_transform_docstring,
+)
 class CategoricalImputer(BaseImputer):
     """
     The CategoricalImputer() replaces missing data in categorical variables by an
     arbitrary value or by the most frequent category.
 
-    The CategoricalVariableImputer() imputes by default only categorical variables
+    The CategoricalImputer() imputes by default only categorical variables
     (type 'object' or 'categorical'). You can pass a list of variables to impute, or
-    alternatively, the encoder will find and encode all categorical variables.
+    alternatively, the encoder will find and impute all categorical variables.
 
     If you want to impute numerical variables with this transformer, there are 2 ways
     of doing it:
 
-    **Option 1**: Cast your numerical variables as object in the input dataframe, before
+    **Option 1**: Cast your numerical variables as object in the input dataframe before
     passing it to the transformer.
 
     **Option 2**: Set `ignore_format=True`. Note that if you do this and do not pass the
     list of variables to impute, the imputer will automatically select and impute all
     variables in the dataframe.
 
+    More details in the :ref:`User Guide <categorical_imputer>`.
+
     Parameters
     ----------
     imputation_method: str, default='missing'
@@ -40,14 +58,14 @@ class CategoricalImputer(BaseImputer):
         or 'missing' to impute with an arbitrary value.
 
     fill_value: str, int, float, default='Missing'
-        Only used when `imputation_method='missing'`. User-defined value to replace the
-        missing data.
+        User-defined value to replace missing data. Only used when
+        `imputation_method='missing'`.
 
     variables: list, default=None
         The list of categorical variables that will be imputed. If None, the
         imputer will find and transform all variables of type object or categorical by
         default. You can also make the transformer accept numerical variables, see the
-        parameter ignore_format below.
+        parameter `ignore_format` below.
 
     return_object: bool, default=False
         If working with numerical variables cast as object, decide
@@ -57,30 +75,30 @@ class CategoricalImputer(BaseImputer):
 
     ignore_format: bool, default=False
         Whether the format in which the categorical variables are cast should be
-        ignored. If false, the encoder will automatically select variables of type
+        ignored. If false, the imputer will automatically select variables of type
         object or categorical, or check that the variables entered by the user are of
-        type object or categorical. If True, the encoder will select all variables or
+        type object or categorical. If True, the imputer will select all variables or
         accept all variables entered by the user, including those cast as numeric.
 
     Attributes
     ----------
-    imputer_dict_:
-        Dictionary with most frequent category or arbitrary value per variable.
+    {imputer_dict_}
 
-    variables_:
-        The group of variables that will be transformed.
+    {variables_}
 
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
     fit:
-        Learn the most frequent category, or assign arbitrary value to variable.
-    transform:
-        Impute missing data.
-    fit_transform:
-        Fit to the data, than transform it.
+        Learn the most frequent category or assign arbitrary value to variable.
+
+    {fit_transform}
+
+    {transform}
+
     """
 
     def __init__(
@@ -117,22 +135,10 @@ class CategoricalImputer(BaseImputer):
 
         y: pandas Series, default=None
             y is not needed in this imputation. You can pass None or y.
-
-        Raises
-        ------
-        TypeError
-            - If the input is not a Pandas DataFrame.
-            - If user enters non-categorical variables (unless ignore_format is True)
-        ValueError
-            If there are no categorical variables in the df or the df is empty
-
-        Returns
-        -------
-        self
         """
 
         # check input dataframe
-        X = _is_dataframe(X)
+        X = check_X(X)
 
         # check or select the the right variables
         if not self.ignore_format:
@@ -149,42 +155,63 @@ class CategoricalImputer(BaseImputer):
             self.imputer_dict_ = {var: self.fill_value for var in self.variables_}
 
         elif self.imputation_method == "frequent":
-            self.imputer_dict_ = {}
 
-            for var in self.variables_:
+            # if imputing only 1 variable:
+            if len(self.variables_) == 1:
+                var = self.variables_[0]
                 mode_vals = X[var].mode()
 
-                # careful: some variables contain multiple modes
-                if len(mode_vals) == 1:
-                    self.imputer_dict_[var] = mode_vals[0]
-                else:
+                # Some variables may contain more than 1 mode:
+                if len(mode_vals) > 1:
                     raise ValueError(
-                        "Variable {} contains multiple frequent categories.".format(var)
+                        f"The variable {var} contains multiple frequent categories."
                     )
 
-        self.n_features_in_ = X.shape[1]
+                self.imputer_dict_ = {var: mode_vals[0]}
+
+            # imputing multiple variables:
+            else:
+                # Returns a dataframe with 1 row if there is one mode per
+                # variable, or more rows if there are more modes:
+                mode_vals = X[self.variables_].mode()
+
+                # Careful: some variables contain multiple modes
+                if len(mode_vals) > 1:
+                    varnames = mode_vals.dropna(axis=1).columns.to_list()
+                    if len(varnames) > 1:
+                        varnames_str = ", ".join(varnames)
+                    else:
+                        varnames_str = varnames[0]
+                    raise ValueError(
+                        f"The variable(s) {varnames_str} contain(s) multiple frequent "
+                        f"categories."
+                    )
+
+                self.imputer_dict_ = mode_vals.iloc[0].to_dict()
+
+        self._get_feature_names_in(X)
 
         return self
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
 
-        X = self._check_transform_input_and_state(X)
-
-        # replaces missing data with the learned parameters
+        # Frequent category imputation
         if self.imputation_method == "frequent":
-            for variable in self.imputer_dict_:
-                X[variable].fillna(self.imputer_dict_[variable], inplace=True)
+            X = super().transform(X)
 
+        # Imputation with string
         else:
-            for variable in self.imputer_dict_:
+            X = self._transform(X)
+
+            # if variable is of type category, we need to add the new
+            # category, before filling in the nan
+            for variable in self.variables_:
                 if pd.api.types.is_categorical_dtype(X[variable]):
-                    # if variable is of type category, we first need to add the new
-                    # category, and then fill in the nan
                     X[variable].cat.add_categories(
                         self.imputer_dict_[variable], inplace=True
                     )
 
-                X[variable].fillna(self.imputer_dict_[variable], inplace=True)
+            X.fillna(self.imputer_dict_, inplace=True)
 
         # add additional step to return variables cast as object
         if self.return_object:
@@ -192,5 +219,11 @@ class CategoricalImputer(BaseImputer):
 
         return X
 
-    # Ugly work around to import the docstring for Sphinx, otherwise not necessary
+    # Get docstring from BaseClass
     transform.__doc__ = BaseImputer.transform.__doc__
+
+    def _more_tags(self):
+        tags_dict = _return_tags()
+        tags_dict["allow_nan"] = True
+        tags_dict["variables"] = "categorical"
+        return tags_dict
