@@ -5,6 +5,7 @@ from .drop_constant_features import DropConstantFeatures
 from .drop_correlated_features import DropCorrelatedFeatures
 from .drop_duplicate_features import DropDuplicateFeatures
 from .drop_features import DropFeatures
+from .drop_psi_features import DropHighPSIFeatures
 from .recursive_feature_addition import RecursiveFeatureAddition
 from .recursive_feature_elimination import RecursiveFeatureElimination
 from .shuffle_features import SelectByShuffling
@@ -17,6 +18,7 @@ __all__ = [
     "DropConstantFeatures",
     "DropDuplicateFeatures",
     "DropCorrelatedFeatures",
+    "DropHighPSIFeatures",
     "SmartCorrelatedSelection",
     "SelectByShuffling",
     "SelectBySingleFeaturePerformance",
