@@ -2,9 +2,20 @@ from typing import List, Union
 
 import pandas as pd
 
-from feature_engine.dataframe_checks import _check_contains_na, _is_dataframe
+from feature_engine.dataframe_checks import _check_contains_na, check_X
+from feature_engine._docstrings.methods import _fit_transform_docstring
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+)
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.selection._docstring import (
+    _missing_values_docstring,
+    _variables_all_docstring,
+    _variables_attribute_docstring,
+)
 from feature_engine.selection.base_selector import BaseSelector
-from feature_engine.validation import _return_tags
+from feature_engine.tags import _return_tags
 from feature_engine.variable_manipulation import (
     _check_input_parameter_variables,
     _find_all_variables,
@@ -13,6 +24,15 @@ from feature_engine.variable_manipulation import (
 Variables = Union[None, int, str, List[Union[str, int]]]
 
 
+@Substitution(
+    confirm_variables=BaseSelector._confirm_variables_docstring,
+    variables=_variables_all_docstring,
+    missing_values=_missing_values_docstring,
+    variables_=_variables_attribute_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    fit_transform=_fit_transform_docstring,
+)
 class DropDuplicateFeatures(BaseSelector):
     """
     DropDuplicateFeatures() finds and removes duplicated features in a dataframe.
@@ -21,18 +41,22 @@ class DropDuplicateFeatures(BaseSelector):
     name. If they show the same values for every observation, then they are considered
     duplicated.
 
+    This transformer works with numerical and categorical variables. The user can
+    indicate a list of variables to examine. Alternatively, the transformer will
+    evaluate all the variables in the dataset.
+
     The transformer will first identify and store the duplicated variables. Next, the
     transformer will drop these variables from a dataframe.
 
+    More details in the :ref:`User Guide <drop_duplicate>`.
+
     Parameters
     ----------
-    variables: list, default=None
-        The list of variables to evaluate. If None, the transformer will evaluate all
-        variables in the dataset.
+    {variables}
 
-    missing_values : str, default=ignore
-        Takes values 'raise' and 'ignore'. Whether the missing values should be raised
-        as error or ignored when finding duplicated features.
+    {missing_values}
+
+    {confirm_variables}
 
     Attributes
     ----------
@@ -42,27 +66,36 @@ class DropDuplicateFeatures(BaseSelector):
     duplicated_feature_sets_:
         Groups of duplicated features. Each list is a group of duplicated features.
 
-    variables_:
-        The variables to consider for the feature selection.
+    {variables_}
 
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
     fit:
         Find duplicated features.
+
+    {fit_transform}
+
     transform:
-        Remove duplicated features
-    fit_transform:
-        Fit to data. Then transform it.
+        Remove duplicated features.
+
     """
 
-    def __init__(self, variables: Variables = None, missing_values: str = "ignore"):
+    def __init__(
+        self,
+        variables: Variables = None,
+        missing_values: str = "ignore",
+        confirm_variables: bool = False,
+    ):
 
         if missing_values not in ["raise", "ignore"]:
             raise ValueError("missing_values takes only values 'raise' or 'ignore'.")
 
+        super().__init__(confirm_variables)
+
         self.variables = _check_input_parameter_variables(variables)
         self.missing_values = missing_values
 
@@ -76,17 +109,19 @@ class DropDuplicateFeatures(BaseSelector):
             The input dataframe.
         y: None
             y is not needed for this transformer. You can pass y or None.
-
-        Returns
-        -------
-        self
         """
 
         # check input dataframe
-        X = _is_dataframe(X)
+        X = check_X(X)
+
+        # If required exclude variables that are not in the input dataframe
+        self._confirm_variables(X)
 
         # find all variables or check those entered are in the dataframe
-        self.variables_ = _find_all_variables(X, self.variables)
+        self.variables_ = _find_all_variables(X, self.variables_)
+
+        # check that there are more than 1 variable to select from
+        self._check_variable_number()
 
         if self.missing_values == "raise":
             # check if dataset contains na
@@ -129,20 +164,17 @@ class DropDuplicateFeatures(BaseSelector):
                 if len(_temp_set) > 1:
                     self.duplicated_feature_sets_.append(_temp_set)
 
-        self.n_features_in_ = X.shape[1]
+        # save input features
+        self._get_feature_names_in(X)
 
         return self
 
-    # Ugly work around to import the docstring for Sphinx, otherwise not necessary
-    def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        X = super().transform(X)
-
-        return X
-
-    transform.__doc__ = BaseSelector.transform.__doc__
-
     def _more_tags(self):
         tags_dict = _return_tags()
-        # add additional test that fails
-        tags_dict["_xfail_checks"]["check_estimators_nan_inf"] = "transformer allows NA"
+        tags_dict["allow_nan"] = True
+        tags_dict["variables"] = "all"
+
+        msg = "transformers need more than 1 feature to work"
+        tags_dict["_xfail_checks"]["check_fit2d_1feature"] = msg
+
         return tags_dict
