@@ -2,13 +2,32 @@ from typing import List, Union
 
 import numpy as np
 import pandas as pd
+from sklearn.base import is_classifier
 from sklearn.metrics import get_scorer
-from sklearn.model_selection import cross_validate
+from sklearn.model_selection import check_cv, cross_validate
 from sklearn.utils.validation import check_random_state
 
-from feature_engine.dataframe_checks import _is_dataframe
+from feature_engine.dataframe_checks import check_X_y
+from feature_engine._docstrings.methods import _fit_transform_docstring
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+)
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.selection._docstring import (
+    _cv_docstring,
+    _estimator_docstring,
+    _features_to_drop_docstring,
+    _fit_docstring,
+    _initial_model_performance_docstring,
+    _scoring_docstring,
+    _threshold_docstring,
+    _transform_docstring,
+    _variables_attribute_docstring,
+    _variables_numerical_docstring,
+)
 from feature_engine.selection.base_selector import BaseSelector
-from feature_engine.validation import _return_tags
+from feature_engine.tags import _return_tags
 from feature_engine.variable_manipulation import (
     _check_input_parameter_variables,
     _find_or_check_numerical_variables,
@@ -17,6 +36,22 @@ from feature_engine.variable_manipulation import (
 Variables = Union[None, int, str, List[Union[str, int]]]
 
 
+@Substitution(
+    estimator=_estimator_docstring,
+    scoring=_scoring_docstring,
+    threshold=_threshold_docstring,
+    cv=_cv_docstring,
+    variables=_variables_numerical_docstring,
+    confirm_variables=BaseSelector._confirm_variables_docstring,
+    initial_model_performance_=_initial_model_performance_docstring,
+    features_to_drop_=_features_to_drop_docstring,
+    variables_=_variables_attribute_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    fit=_fit_docstring,
+    transform=_transform_docstring,
+    fit_transform=_fit_transform_docstring,
+)
 class SelectByShuffling(BaseSelector):
     """
     SelectByShuffling() selects features by determining the drop in machine learning
@@ -25,14 +60,13 @@ class SelectByShuffling(BaseSelector):
     If the variables are important, a random permutation of their values will
     decrease dramatically the machine learning model performance. Contrarily, the
     permutation of the values should have little to no effect on the model performance
-    metric we are assessing.
+    metric we are assessing if the feature is not predictive.
 
     The SelectByShuffling() first trains a machine learning model utilising all
     features. Next, it shuffles the values of 1 feature, obtains a prediction with the
     pre-trained model, and determines the performance drop (if any). If the drop in
     performance is bigger than a threshold then the feature is retained, otherwise
-    removed. It continues until all features have been shuffled and the drop in
-    performance evaluated.
+    removed. It continues until all features have been shuffled and examined.
 
     The user can determine the model for which performance drop after feature shuffling
     should be assessed. The user also determines the threshold in performance under
@@ -40,76 +74,57 @@ class SelectByShuffling(BaseSelector):
 
     Model training and performance calculation are done with cross-validation.
 
+    More details in the :ref:`User Guide <feature_shuffling>`.
+
     Parameters
     ----------
-    estimator: object
-        A Scikit-learn estimator for regression or classification.
+    {estimator}
 
-    variables: str or list, default=None
-        The list of variable(s) to be shuffled from the dataframe.
-        If None, the transformer will shuffle all numerical variables in the dataset.
+    {variables}
 
-    scoring: str, default='roc_auc'
-        Desired metric to optimise the performance for the estimator. Comes from
-        sklearn.metrics. See the model evaluation documentation for more options:
-        https://scikit-learn.org/stable/modules/model_evaluation.html
+    {scoring}
 
-    threshold: float, int, default = None
-        The value that defines if a feature will be kept or removed. Note that for
-        metrics like roc-auc, r2_score and accuracy, the thresholds will be floats
-        between 0 and 1. For metrics like the mean_square_error and the
-        root_mean_square_error the threshold will be a big number. The threshold can be
-        defined by the user. If None, the selector will select features which
-        performance drift is smaller than the mean performance drift across all
-        features.
+    {threshold}
 
-    cv: int, cross-validation generator or an iterable, default=3
-        Determines the cross-validation splitting strategy. Possible inputs for cv are:
-
-            - None, to use cross_validate's default 5-fold cross validation
-
-            - int, to specify the number of folds in a (Stratified)KFold,
-
-            - CV splitter
-                - (https://scikit-learn.org/stable/glossary.html#term-CV-splitter)
-
-            - An iterable yielding (train, test) splits as arrays of indices.
-
-        For int/None inputs, if the estimator is a classifier and y is either binary or
-        multiclass, StratifiedKFold is used. In all other cases, Fold is used. These
-        splitters are instantiated with shuffle=False so the splits will be the same
-        across calls.
-
-        For more details check Scikit-learn's cross_validate documentation
+    {cv}
 
     random_state: int, default=None
         Controls the randomness when shuffling features.
 
+    {confirm_variables}
+
     Attributes
     ----------
-    initial_model_performance_:
-        Performance of the model trained using the original dataset.
+    {initial_model_performance_}
 
     performance_drifts_:
         Dictionary with the performance drift per shuffled feature.
 
-    features_to_drop_:
-        List with the features to remove from the dataset.
+    {features_to_drop_}
 
-    variables_:
-        The variables to consider for the feature selection.
+    {variables_}
 
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
-    fit:
-        Find the important features.
-    transform:
-        Reduce X to the selected features.
-    fit_transform:
-        Fit to data, then transform it.
+    {fit}
+
+    {fit_transform}
+
+    {transform}
+
+    Notes
+    -----
+    This transformer is a similar concept to the `permutation_importance` from
+    Scikit-learn. The function in Scikit-learn is used to evaluate feature importance
+    instead of to select features.
+
+    See Also
+    --------
+    sklearn.inspection.permutation_importance
     """
 
     def __init__(
@@ -120,11 +135,14 @@ class SelectByShuffling(BaseSelector):
         threshold: Union[float, int] = None,
         variables: Variables = None,
         random_state: int = None,
+        confirm_variables: bool = False,
     ):
 
         if threshold and not isinstance(threshold, (int, float)):
             raise ValueError("threshold can only be integer or float or None")
 
+        super().__init__(confirm_variables)
+
         self.variables = _check_input_parameter_variables(variables)
         self.estimator = estimator
         self.scoring = scoring
@@ -139,26 +157,25 @@ class SelectByShuffling(BaseSelector):
         Parameters
         ----------
         X: pandas dataframe of shape = [n_samples, n_features]
-           The input dataframe
+           The input dataframe.
         y: array-like of shape (n_samples)
            Target variable. Required to train the estimator.
-
-        Returns
-        -------
-        self
         """
 
-        # check input dataframe
-        X = _is_dataframe(X)
+        X, y = check_X_y(X, y)
 
         # reset the index
         X = X.reset_index(drop=True)
+        y = y.reset_index(drop=True)
 
-        if isinstance(y, pd.Series):
-            y = y.reset_index(drop=True)
+        # If required exclude variables that are not in the input dataframe
+        self._confirm_variables(X)
 
         # find numerical variables or check variables entered by user
-        self.variables_ = _find_or_check_numerical_variables(X, self.variables)
+        self.variables_ = _find_or_check_numerical_variables(X, self.variables_)
+
+        # check that there are more than 1 variable to select from
+        self._check_variable_number()
 
         # train model with all features and cross-validation
         model = cross_validate(
@@ -173,6 +190,10 @@ class SelectByShuffling(BaseSelector):
         # store initial model performance
         self.initial_model_performance_ = model["test_score"].mean()
 
+        # extract the validation folds
+        cv_ = check_cv(self.cv, y=y, classifier=is_classifier(self.estimator))
+        validation_indices = [val_index for _, val_index in cv_.split(X, y)]
+
         # get performance metric
         scorer = get_scorer(self.scoring)
 
@@ -196,7 +217,10 @@ class SelectByShuffling(BaseSelector):
 
             # determine the performance with the shuffled feature
             performance = np.mean(
-                [scorer(m, X_shuffled, y) for m in model["estimator"]]
+                [
+                    scorer(m, X_shuffled.iloc[idx], y.iloc[idx])
+                    for m, idx in zip(model["estimator"], validation_indices)
+                ]
             )
 
             # determine drift in performance
@@ -222,23 +246,22 @@ class SelectByShuffling(BaseSelector):
             if self.performance_drifts_[f] < threshold
         ]
 
-        self.n_features_in_ = X.shape[1]
+        # save input features
+        self._get_feature_names_in(X)
 
         return self
 
-    # Ugly work around to import the docstring for Sphinx, otherwise not necessary
-    def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        X = super().transform(X)
-
-        return X
-
-    transform.__doc__ = BaseSelector.transform.__doc__
-
     def _more_tags(self):
         tags_dict = _return_tags()
+        tags_dict["variables"] = "numerical"
+        tags_dict["requires_y"] = True
         # add additional test that fails
         tags_dict["_xfail_checks"]["check_estimators_nan_inf"] = "transformer allows NA"
         tags_dict["_xfail_checks"][
             "check_parameters_default_constructible"
         ] = "transformer has 1 mandatory parameter"
+
+        msg = "transformers need more than 1 feature to work"
+        tags_dict["_xfail_checks"]["check_fit2d_1feature"] = msg
+
         return tags_dict
