@@ -1,8 +1,7 @@
 import pandas as pd
 import pytest
-from sklearn.exceptions import NotFittedError
 
-from feature_engine.encoding import MeanEncoder, OrdinalEncoder
+from feature_engine.encoding import MeanEncoder
 
 
 def test_user_enters_1_variable(df_enc):
@@ -114,23 +113,34 @@ def test_automatically_find_variables(df_enc):
     pd.testing.assert_frame_equal(X, transf_df[["var_A", "var_B"]])
 
 
-def test_error_if_y_not_passed_to_fit(df_enc):
-    # test case 3: raises error if target is not passed
-    with pytest.raises(TypeError):
-        encoder = MeanEncoder()
-        encoder.fit(df_enc)
-
-
 def test_warning_if_transform_df_contains_categories_not_present_in_fit_df(
     df_enc, df_enc_rare
 ):
     # test case 4: when dataset to be transformed contains categories not present
     # in training dataset
-    with pytest.warns(UserWarning):
-        encoder = MeanEncoder()
+
+    msg = "During the encoding, NaN values were introduced in the feature(s) var_A."
+
+    # check for warning when rare_labels equals 'ignore'
+    with pytest.warns(UserWarning) as record:
+        encoder = MeanEncoder(errors="ignore")
         encoder.fit(df_enc[["var_A", "var_B"]], df_enc["target"])
         encoder.transform(df_enc_rare[["var_A", "var_B"]])
 
+    # check that only one warning was raised
+    assert len(record) == 1
+    # check that the message matches
+    assert record[0].message.args[0] == msg
+
+    # check for error when rare_labels equals 'raise'
+    with pytest.raises(ValueError) as record:
+        encoder = MeanEncoder(errors="raise")
+        encoder.fit(df_enc[["var_A", "var_B"]], df_enc["target"])
+        encoder.transform(df_enc_rare[["var_A", "var_B"]])
+
+    # check that the error message matches
+    assert str(record.value) == msg
+
 
 def test_fit_raises_error_if_df_contains_na(df_enc_na):
     # test case 4: when dataset contains na, fit method
@@ -147,12 +157,6 @@ def test_transform_raises_error_if_df_contains_na(df_enc, df_enc_na):
         encoder.transform(df_enc_na)
 
 
-def test_raises_non_fitted_error(df_enc):
-    with pytest.raises(NotFittedError):
-        imputer = OrdinalEncoder()
-        imputer.transform(df_enc)
-
-
 def test_user_enters_1_variable_ignore_format(df_enc_numeric):
     # test case 1: 1 variable
     encoder = MeanEncoder(variables=["var_A"], ignore_format=True)
@@ -293,3 +297,8 @@ def test_variables_cast_as_category(df_enc_category_dtypes):
 
     pd.testing.assert_frame_equal(X, transf_df[["var_A", "var_B"]], check_dtype=False)
     assert X["var_A"].dtypes == float
+
+
+def test_error_if_rare_labels_not_permitted_value():
+    with pytest.raises(ValueError):
+        MeanEncoder(errors="empanada")
