@@ -1,10 +1,32 @@
 import pandas as pd
 import pytest
-from sklearn.exceptions import NotFittedError
 
 from feature_engine.selection import DropFeatures
 
 
+def test_drop_1_variable(df_vartypes):
+    transformer = DropFeatures(features_to_drop="City")
+    X = transformer.fit_transform(df_vartypes)
+
+    # expected result
+    df = pd.DataFrame(
+        {
+            "Name": ["tom", "nick", "krish", "jack"],
+            "Age": [20, 21, 19, 18],
+            "Marks": [0.9, 0.8, 0.7, 0.6],
+            "dob": pd.date_range("2020-02-24", periods=4, freq="T"),
+        }
+    )
+
+    # init params
+    assert transformer.features_to_drop == "City"
+
+    # transform params
+    assert X.shape == (4, 4)
+    assert type(X) == pd.DataFrame
+    pd.testing.assert_frame_equal(X, df)
+
+
 def test_drop_2_variables(df_vartypes):
     transformer = DropFeatures(features_to_drop=["City", "dob"])
     X = transformer.fit_transform(df_vartypes)
@@ -20,8 +42,7 @@ def test_drop_2_variables(df_vartypes):
 
     # init params
     assert transformer.features_to_drop == ["City", "dob"]
-    # fit attr
-    assert transformer.n_features_in_ == 5
+
     # transform params
     assert X.shape == (4, 3)
     assert type(X) == pd.DataFrame
@@ -35,13 +56,6 @@ def test_error_if_non_existing_variables(df_vartypes):
         transformer.fit_transform(df_vartypes)
 
 
-def test_error_if_fit_input_not_dataframe():
-    # test case 3: passing a different input than dataframe
-    with pytest.raises(TypeError):
-        transformer = DropFeatures(features_to_drop=["Name"])
-        transformer.fit({"Name": ["Karthik"]})
-
-
 def test_error_when_returning_empty_dataframe(df_vartypes):
     # test case 5: dropping all columns produces warning check
     with pytest.raises(ValueError):
@@ -71,14 +85,5 @@ def test_drop_2_variables_integer_colnames(df_numeric_columns):
 
     # init params
     assert transformer.features_to_drop == [0, 1]
-    # fit attr
-    assert transformer.n_features_in_ == 5
     # transform params
     pd.testing.assert_frame_equal(X, df)
-
-
-def test_non_fitted_error(df_numeric_columns):
-    # test case 8: when fit is not called prior to transform
-    with pytest.raises(NotFittedError):
-        transformer = DropFeatures(features_to_drop=[0, 1])
-        transformer.transform(df_numeric_columns)
